
From: Pavel Machek <pavel@ucw.cz>

Fix error printing in swsusp.c: add loglevels and add very usefull error
information.  Trivial cleanup for disk.c.

Signed-off-by: Pavel Machek <pavel@suse.cz>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 kernel/power/disk.c   |    8 ++------
 kernel/power/swsusp.c |    3 ++-
 2 files changed, 4 insertions(+), 7 deletions(-)

diff -puN kernel/power/disk.c~swsusp-fix-printks-and-cleanups kernel/power/disk.c
--- 25/kernel/power/disk.c~swsusp-fix-printks-and-cleanups	Wed Jul 13 17:56:59 2005
+++ 25-akpm/kernel/power/disk.c	Wed Jul 13 17:56:59 2005
@@ -52,21 +52,17 @@ static void power_down(suspend_disk_meth
 	unsigned long flags;
 	int error = 0;
 
+	device_shutdown();
+	local_irq_save(flags);
 	switch(mode) {
 	case PM_DISK_PLATFORM:
-		device_shutdown();
-		local_irq_save(flags);
 		error = pm_ops->enter(PM_SUSPEND_DISK);
 		break;
 	case PM_DISK_SHUTDOWN:
 		printk("Powering off system\n");
-		device_shutdown();
-		local_irq_save(flags);
 		machine_power_off();
 		break;
 	case PM_DISK_REBOOT:
-		device_shutdown();
-		local_irq_save(flags);
 		machine_restart(NULL);
 		break;
 	}
diff -puN kernel/power/swsusp.c~swsusp-fix-printks-and-cleanups kernel/power/swsusp.c
--- 25/kernel/power/swsusp.c~swsusp-fix-printks-and-cleanups	Wed Jul 13 17:56:59 2005
+++ 25-akpm/kernel/power/swsusp.c	Wed Jul 13 17:56:59 2005
@@ -886,6 +886,7 @@ int swsusp_suspend(void)
 	 * at resume time, and evil weirdness ensues.
 	 */
 	if ((error = device_power_down(PMSG_FREEZE))) {
+		printk(KERN_ERR "Some devices failed to power down, aborting suspend\n");
 		local_irq_enable();
 		return error;
 	}
@@ -899,7 +900,7 @@ int swsusp_suspend(void)
 
 	save_processor_state();
 	if ((error = swsusp_arch_suspend()))
-		printk("Error %d suspending\n", error);
+		printk(KERN_ERR "Error %d suspending\n", error);
 	/* Restore control flow magically appears here */
 	restore_processor_state();
 	BUG_ON (nr_copy_pages_check != nr_copy_pages);
_
